@@ -159,6 +159,8 @@ class DB:
                 "ExpressionAttributeValues": expression_values,
             }
         try:
+            if self._logger:
+                self._logger.debug("DynamoDB PUT", extra=kwargs)
             self._table.put_item(**kwargs)
         except botocore.exceptions.ClientError as e:
             if e.response["Error"]["Code"] == "ConditionalCheckFailedException":
@@ -230,12 +232,16 @@ class DB:
             kwargs["ExpressionAttributeValues"] = expression_values
 
         try:
+            if self._logger:
+                self._logger.debug("DynamoDB UPDATE", extra=kwargs)
             self._table.update_item(**kwargs)
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
 
     def _delete(self, key: ItemKey):
         try:
+            if self._logger:
+                self._logger.debug("DynamoDB DELETE", extra={"Key": key.as_dynamodb_key()})
             self._table.delete_item(Key=key.as_dynamodb_key())
         except botocore.exceptions.ClientError as e:
             raise InternalError() from e
